package repositories

import (
	"github.com/dungnt11/senflow_app/internal/models"
	"gorm.io/gorm"
)

// UserRepository triển khai IUserRepository
type UserRepository struct {
	db *gorm.DB
}

// NewUserRepository tạo một instance mới của UserRepository
func NewUserRepository(db *gorm.DB) *UserRepository {
	return &UserRepository{
		db: db,
	}
}

// Create tạo một user mới trong database
func (ur *UserRepository) Create(user *models.User) error {
	return ur.db.Create(user).Error
}

// FindByID tìm user theo ID
func (ur *UserRepository) FindByID(id uint) (*models.User, error) {
	var user models.User
	err := ur.db.First(&user, id).Error
	if err != nil {
		return nil, err
	}
	return &user, nil
}

// FindByUsername tìm user theo username
func (ur *UserRepository) FindByUsername(username string) (*models.User, error) {
	var user models.User
	err := ur.db.Where("username = ?", username).First(&user).Error
	if err != nil {
		return nil, err
	}
	return &user, nil
}

// Update cập nhật thông tin user
func (ur *UserRepository) Update(user *models.User) error {
	return ur.db.Save(user).Error
}

// Delete xóa user theo ID
func (ur *UserRepository) Delete(id uint) error {
	return ur.db.Delete(&models.User{}, id).Error
}
